@@ -32,7 +32,9 @@
         or die("Unable to select database");
 
     if (minimum_version('4.1.0')) {
-        $user = $_SESSION['user'];
+        if (array_key_exists('user', $_SESSION)) {
+            $user = $_SESSION['user'];
+        }
     }
 
     // no user was in the session, try logging in
@@ -83,7 +85,7 @@
                 // "display".
                 $redirect_clean=preg_replace("/action=(?!search).[^&]+/", "action=display", $redirect);
                 if(FORCE_SSL_LOGIN && !FORCE_SSL) {
-                    $redirect_clean = "http://" . $_SERVER['SERVER_NAME'] . "/" . $redirect_clean;
+                    $redirect_clean = "http://" . $_SERVER['SERVER_NAME'] . $redirect_clean;
                 }
                 header("Location: " . $redirect_clean);
             }
