@@ -32,6 +32,10 @@ class category extends zoph_tree_table {
         parent::delete(array("photo_categories"));
     }
 
+    function get_name() {
+        return $this->get("category");
+    }
+
     function get_children() {
         return parent::get_children(null, "category");
     }
@@ -49,15 +53,15 @@ class category extends zoph_tree_table {
         if ($user && !$user->is_admin()) {
             $sql =
                 "select count(distinct pc.photo_id) from " .
-                DB_PREFIX . "photo_categories as pc, " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "photos as p, " .
+                DB_PREFIX . "photo_categories as pc JOIN " .
+                DB_PREFIX . "photo_albums as pa " .
+                " ON pc.photo_id = pa.photo_id JOIN " .
+                DB_PREFIX . "photos as p " .
+                " ON pa.photo_id = p.photo_id JOIN " .
                 DB_PREFIX . "album_permissions as ap " .
+                " ON pa.album_id = ap.album_id " .
                 "where pc.category_id = '" .  escape_string($id) . "'" .
                 " and ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-                " and pc.photo_id = pa.photo_id" .
-                " and pa.album_id = ap.album_id" .
-                " and pa.photo_id = p.photo_id" .
                 " and ap.access_level >= p.level";
         }
         else {
@@ -83,14 +87,14 @@ class category extends zoph_tree_table {
         if ($user && !$user->is_admin()) {
             $sql =
                 "select count(distinct pc.photo_id) from " .
-                DB_PREFIX . "photo_categories as pc, " .
-                DB_PREFIX . "photo_albums as pa, " .
-                DB_PREFIX . "photos as p, " .
+                DB_PREFIX . "photo_categories as pc JOIN " .
+                DB_PREFIX . "photo_albums as pa " .
+                " ON pc.photo_id = pa.photo_id JOIN " .
+                DB_PREFIX . "photos as p " .
+                " ON pa.photo_id = p.photo_id JOIN " .
                 DB_PREFIX . "album_permissions as ap " .
-                "where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
-                " and pc.photo_id = pa.photo_id" .
-                " and pa.album_id = ap.album_id" .
-                " and pa.photo_id = p.photo_id" .
+                " ON pa.album_id = ap.album_id" .
+                " where ap.user_id = '" . escape_string($user->get("user_id")) . "'" .
                 " and ap.access_level >= p.level";
 
             if ($id_constraint) {
@@ -112,17 +116,25 @@ class category extends zoph_tree_table {
 
     function get_edit_array() {
         return array(
-            translate("category name") =>
-                create_text_input("category", $this->get("category")),
-            translate("parent category") =>
-                create_pulldown("parent_category_id",
-                    $this->get("parent_category_id"),
-                    get_categories_select_array()),
-            translate("category description") =>
-                create_text_input("category_description",
-                    $this->get("category_description"), 40, 128),
-            translate("category sort order") =>
-                create_photo_field_pulldown("sortorder", $this->get("sortorder"))
+            "category" =>
+                array(
+                    translate("category name"),
+                    create_text_input("category", $this->get("category"))),
+            "parent_category_id" =>
+                array(
+                    translate("parent category"),
+                    create_pulldown("parent_category_id",
+                        $this->get("parent_category_id"),
+                        get_categories_select_array())),
+            "category_description" =>
+                array(
+                    translate("category description"),
+                    create_text_input("category_description",
+                        $this->get("category_description"), 40, 128)),
+            "sortorder" =>
+                array(
+                    translate("category sort order"),
+                    create_photo_field_pulldown("sortorder", $this->get("sortorder")))
         );
     }
 
@@ -135,6 +147,52 @@ class category extends zoph_tree_table {
         }
         return "<a href=\"categories.php?parent_category_id=" . $this->get("category_id") . "\">$name</a>";
     }
+    function xml_rootname() {
+        return "categories";
+    }
+
+    function xml_nodename() {
+        return "category";
+    }
+
+    function get_coverphoto($user,$autothumb=null) {
+        if ($this->get("coverphoto")) {
+            $coverphoto=new photo($this->get("coverphoto"));
+        } else if ($autothumb) {
+            $order=get_autothumb_order($autothumb);
+            if ($user && !$user->is_admin()) {
+                $sql=
+                    "select distinct p.photo_id from " .
+                    DB_PREFIX . "photos as p JOIN " .
+                    DB_PREFIX . "photo_albums as pa" .
+                    " ON pa.photo_id = p.photo_id JOIN " .
+                    DB_PREFIX . "album_permissions as ap " .
+                    " ON pa.album_id = ap.album_id JOIN " .
+                    DB_PREFIX . "photo_categories as pc " .
+                    " ON pc.photo_id = p.photo_id " .
+                    " WHERE pc.category_id = " . $this->get("category_id") .
+                    " AND ap.user_id =" .
+                    " '" . escape_string($user->get("user_id")) . "'" .
+                    " and ap.access_level >= p.level " .
+                    $order;
+            } else {
+                $sql =
+                    "select distinct p.photo_id from " .
+                    DB_PREFIX . "photos as p JOIN " .
+                    DB_PREFIX . "photo_categories as pc ON" .
+                    " pc.photo_id = p.photo_id" .
+                    " WHERE pc.category_id = " . $this->get("category_id") .
+                    " " . $order;
+            }
+            $coverphoto=array_shift(get_records_from_query("photo", $sql));
+        }
+
+        if ($coverphoto) {
+            $coverphoto->lookup();
+            return $coverphoto->get_image_tag(THUMB_PREFIX);
+        }
+    }
+
 
 }
 
