@@ -17,8 +17,7 @@
  */
 
 header("Content-Type: text/css");
-
-if ( $_GET['logged_on']=="no" ) {
+if(isset($_GET['logged_on'])) {
     require_once("config.inc.php");
     require_once("zoph_table.inc.php");
     require_once("user.inc.php");
@@ -79,6 +78,7 @@ h2  {
     text-align: left;
     font-size: large;
     margin: 0;
+    margin-top: 10px;
     margin-bottom: 10px;
     }
 
@@ -100,26 +100,140 @@ ul  {
     margin: 0.5em 1em 1em 1em;
     }
 
+ul.thumbs {
+    clear: both;
+    list-style: none;
+    }
+
+ul.thumbs li {
+    background: <?php echo $TITLE_BG_COLOR ?>;
+    color: <?php echo $TITLE_FONT_COLOR ?>;
+    border: 1px solid <?php echo $TABLE_BORDER_COLOR ?>; 
+    border-radius: 10px;
+    position: relative;
+    display: block;
+    text-align: center;
+    width: 160px;
+    height: 180px;
+    float:left;
+    margin: 5px;
+    padding: 5px;
+    -moz-border-radius: 10px;
+    }
+
+ul.thumbs li p {
+    display: block;
+    margin-left: auto;
+    margin-right: auto;
+    min-height: 120px;
+    }
+
+ul.thumbs li img {
+    display: block;
+    margin-left: auto;
+    margin-right: auto;
+}
+
+ul.thumbs li div {
+    position: absolute;
+    bottom: 0px;
+    text-align: center;
+    width: 90%;
+    }
+
+ul.list {
+    clear: both;
+    list-style: none;
+    }
+
+ul.tree {
+    clear: both;
+    list-style: none;
+    }
+
+ul.tree ul {
+    list-style: none;
+    margin-top: 0;
+    margin-bottom: 0;
+    }
+
+ul.tree ul ul {
+    display: none;
+    }
+
+ul.thumbs a {
+    text-align: center;
+    }
 /* Form properties */
 form    {
     margin: 0 0 0 0;
     width: 100%;
     }
 
-form#quicknav   {
-    float: right;
+form.viewsettings {
     clear: both;
     width: auto;
     margin: 0;
     padding: 0;
     }
 
-form#quicknav select {
+form.viewsettings select {
+    margin-right: 15px;
+    }
+
+
+form.viewsettings select#parent_place_id {
+    float: right;
     clear: none;
-    margin: 0px;
+    margin-right: 0;
     width: 10em;
     }
 
+form#ratingform input, form#ratingform select {
+    margin: 0;
+    float: left;
+    }
+
+form#ratingform select {
+    margin-top: 4px;
+    margin-right: 5px;
+    }
+
+ul.autocompdropdown {
+    position: relative;
+    background: <?php echo $PAGE_BG_COLOR ?>;
+    width: 300px;
+    border: 1px solid <?php echo $TABLE_BORDER_COLOR ?>; 
+    max-height: 15em;
+    overflow: auto;
+    margin: 0;
+    padding: 0;
+    z-index: 5;
+    }
+
+ul.autocompdropdown ul {
+    margin: 0 0 0 1em;
+    padding-left: 0em;
+    }
+
+ul.autocompdropdown li {
+    list-style: none;
+    margin: 0;
+    padding: 0 10px 0 10px;
+}
+
+input.autocompinput {
+    background: white url('images/down2.gif');
+    background-repeat: no-repeat;
+    background-position: center right;
+
+    }
+
+ul.autocompdropdown li:hover,
+ul.autocompdropdown li#selected {
+    background: <?php echo $TAB_BG_COLOR ?>;
+}
+
 /* Menubar */
 
 ul.menu {
@@ -220,8 +334,6 @@ p.main, p.info {
     padding: 4px;
     }
 
-table.info > col { width: 50%; }
-
 /* The short introduction on zoph.php */
 .intro  {
     padding: 5px;
@@ -266,15 +378,6 @@ div.ratings   {
     background: <?php echo $BREADCRUMB_BG_COLOR ?>;
     }
 
-table.places {
-    width: 100%;
-    }
-
-table.places td {
-    padding-left: 5px;
-    padding-right: 5px;
-    }
-
 table#search input[type="checkbox"] {
     float: none;
     }
@@ -294,7 +397,7 @@ table#search input[type="checkbox"] + label {
 
 /* Links that appear on the right hand side of the title bar or page */
 
-span.actionlink {
+span.actionlink, div.actionlink {
     margin: 1px;
     text-align: right;
     vertical-align: top;
@@ -302,7 +405,11 @@ span.actionlink {
     float: right;
     font-weight: normal;
     }
-    
+
+span.photocount {
+    font-size: x-small;
+    }
+
 .actionlink:before, div.letter:before {
     content: "[ ";
     }
@@ -341,6 +448,7 @@ span.actionlink {
     border:  4px solid <?php echo $TITLE_BG_COLOR ?>;
     font-size: small;
     background: <?php echo $TABLE_BG_COLOR ?>;
+    clear: both;
     }
 /* The description of a photo in thumbnail view */
 .thumbdesc  {
@@ -355,16 +463,17 @@ span.actionlink {
 
 
 
-/* Tables for the color scheme */
+/* Color scheme */
 
-table.colors {
-    margin-left: auto; /* To center the page */
-    margin-right: auto;
-    }   
+div.colordef {
+    margin-left: 1em;
+    float: left;
+    width: 10em;
+    }
 
-table.colors > td, table.colors > th    {
-    padding-left: 10px;
-    padding-right: 10px;
+div.color {
+    float: left;
+    width: 60px;
     }
 
 /* Tables for the permissions */
@@ -450,9 +559,9 @@ div#photohdr {
 /* Form on top of each photopage to determine sortorder, asc or desc and
    number of photos displayes */
 
-
 div#sortorder {
     float: left;
+    margin-right: 15px;
     margin-bottom: 15px;
     }
 
@@ -463,7 +572,6 @@ div#updown {
 
 div#rowscols {
     float: right;
-    clear: right;
     margin-bottom: 15px;
     }
 
@@ -509,12 +617,6 @@ span.inputhint  {
     text-align: right;
     }
 
-.fieldtitle-centered    {
-    text-align: center;
-    vertical-align: top;
-    font-weight: bold;
-    }
-
 div.editchoice  {
     vertical-align: top;
     clear: none;
@@ -597,19 +699,53 @@ br.noclear {
     width: 90%
     }
 
-.field, .fieldtitle, .fieldtitle-centered, label    { 
+label, dt, dd    { 
     font-size: medium; 
     padding-left: 4px;
     padding-right: 4px;
     }
 
-.fieldtitle, label  {
+dd {
+    float: left;
+    clear: right;
+    margin-top: 5px;
+    margin-bottom: 5px;
+    }
+
+dt {
+    clear: left;
+    float: left;
+    width: 10em;
+    font-weight: bold;
+    text-align: right;
+    margin-top: 5px;
+    margin-bottom: 5px;
+    }
+
+dl  {
+    margin-top: 0px;
+    margin-bottom: 30px;
+    /* Workaround for Firefox bug */
+    border: 1px solid transparent;
+    }
+
+dl.prefs dt {
+    width: 25em;
+    }
+
+dl#allexif {
+    display: none;
+    width: 100%;
+    }
+
+dl#allexif dl {
+    width: 100%
+    }
+
+label, table#credits th {
     text-align: right;
     vertical-align: top;
     font-weight: bold;
-    }
-
-label   {
     margin-left: 1em;
     margin-bottom: 10px;
     width: 10em;
@@ -618,10 +754,15 @@ label   {
     clear: none;
     }
 
+label {
+    clear: left;
+    }
+
 /* This is to get the labels in a nice column, even if there's a checkbox
 next to it, like on the Annotate photo page */
 
 input[type="checkbox"] + label {
+    clear: none;
     width: 9em;
     }
 
@@ -693,6 +834,11 @@ input[type="reset"] {
     display: block;
     }
 
+div#rowscols input[type="submit"] {
+    display: inline;
+    margin: 0px 15px 0px 15px;
+    }
+
 input[type="submit"].updatebutton {
     clear: right;
     margin-right: 15px;
@@ -706,6 +852,10 @@ input[type="submit"].increment {
     height: auto;
     }
 
+input[type="submit"].bigbutton {
+    width: 200px !important;
+    }
+
 textarea {
     margin: 2px;
     width: 70%;
@@ -730,6 +880,10 @@ input[type="checkbox"] {
     float: left;
     }
 
+input[type="checkbox"].remove {
+    clear: left;
+    }
+
 div#logon input[type="text"],
 div#logon input[type="password"],
 div#passwordchange input[type="text"],
@@ -743,28 +897,12 @@ input, select {
     }
 
 table#users,
-table#credits, 
-table#user, 
-table#slideshow, 
-table#place,
-table#photo,
-table#editperson,
 table#credits {
     width: 100%;
     }
 
-table.editphotos {
-    width: 350px;
-    }
-
 table#users td, 
-table#credits td, 
-table#user td,
-table#slideshow td,
-table#place td,
-table#photo td, 
-table#editperson td,
-table.editphotos td {
+table#credits td { 
     margin: 2px;
     }
 
@@ -774,20 +912,18 @@ table#zophinfo {
     margin-right: auto;
     }
 
-table#zophinfo td.fieldtitle {
+table#zophinfo th {
     width: 80%;
     }
 
-table#zophinfo td.field {
+table#zophinfo td {
     width: 20%;
     }
     
 div#rowscols select,
 div#rowscols input,
 div#rotate select,
-div#rotate input,
-table#photo select,
-table#photo input {
+div#rotate input {
     margin: 0;
     }
 
@@ -802,9 +938,6 @@ div#rotate input[type="submit"] {
     margin-right: auto;
     }
 
-/* This is a temporary style to workaround this bug: http://bugzilla.mozilla.org/show_bug.cgi?id=241317 */
-.bigbutton { width: 200px !important; }
-
 /* Styles for calendar */
 
 .calendar { 
@@ -821,10 +954,6 @@ div#rotate input[type="submit"] {
 
 .calendar .next, .calendar .prev { font-size: x-small; }
 
-/* Styles to control alignment - not really semantically correct - should change in the future */
-.right  { text-align: right; }
-.center { text-align: center; }
-
 /* Error message */
 .error  {
     text-align: center;
