@@ -148,36 +148,34 @@
 
     if ($_action != "mail") {
 ?>
-<input type="hidden" name="_action" value="mail">
+        <input type="hidden" name="_action" value="mail">
 <?php
         if ($shownewalbums) {
 ?>
-<input type="hidden" name="setlastmodified" value="1">
+            <input type="hidden" name="setlastmodified" value="1">
 <?php
         }
 ?>
-<input type="hidden" name="user_id" value="<?php echo $user_id ?>">
-          <label for="to_name"><?php echo translate("to (name)") ?>:</label>
+            <input type="hidden" name="user_id" value="<?php echo $user_id ?>">
+            <label for="to_name"><?php echo translate("to (name)") ?>:</label>
             <?php echo create_text_input("to_name", $to_name, 24, 32) ?><br>
-          <label for="to_email"><?php echo translate("to (email)") ?>:</label>
+            <label for="to_email"><?php echo translate("to (email)") ?>:</label>
             <?php echo create_text_input("to_email", $to_email, 24, 32) ?><br>
-          <label for="from_name"><?php echo translate("from (your name)") ?>:</label>
+            <label for="from_name"><?php echo translate("from (your name)") ?>:</label>
             <?php echo create_text_input("from_name", $from_name, 24, 32) ?><br>
-          <label for="from_email"><?php echo translate("from (your email)") ?>:</label>
+            <label for="from_email"><?php echo translate("from (your email)") ?>:</label>
             <?php echo create_text_input("from_email", $from_email, 24, 64) ?><br>
-          <label for="subject"><?php echo translate("subject") ?>:</label>
+            <label for="subject"><?php echo translate("subject") ?>:</label>
             <?php echo create_text_input("subject", $subject, 48, 64) ?><br>
             
-	   <label for="message"><?php echo translate("message:") ?></label><br>
+	        <label for="message"><?php echo translate("message:") ?></label><br>
             <textarea name="message" class="email" cols="70" rows="15"><?php echo $message ?></textarea><br>
-          <div class="center">
             <input type="submit" name="_button" value="<?php echo translate("email", 0); ?>">
-	    <br>
-          </div>
+	        <br>
 <?php
     }
 ?>
-</form>
+        </form>
     </div>
 <?php
     require_once("footer.inc.php");
