@@ -81,17 +81,15 @@ class photo extends zoph_table {
             "photo_albums"));
     }
 
-    function update($vars = null, $suffix = '') {
+    function update($vars = null, $suffix = '', $user=null) {
         parent::update();
-
         if (!$vars) { return; }
-
-        $this->update_relations($vars, $suffix);
+        $this->update_relations($vars, $suffix, $user);
     }
 
-    function update_relations($vars, $suffix = '') {
+    function update_relations($vars, $suffix = '', $user=null) {
         if ($vars["_album$suffix"]) {
-            $this->add_to_album($vars["_album$suffix"]);
+            $this->add_to_album($vars["_album$suffix"], $user);
         }
 
         if ($vars["_remove_album$suffix"]) {
@@ -121,13 +119,27 @@ class photo extends zoph_table {
         }
     }
 
-    function add_to_album($album_id) {
-        $sql =
-            "insert into " . DB_PREFIX . "photo_albums " .
-            "(photo_id, album_id) values ('" .
+    function add_to_album($album_id, $user=null) {
+        // This is only done when either $user has write permissions to the
+        // album, when the user is admin or when $user = null, this is to
+        // retain compatibility with calls from import, which checks user
+        // permissions before calling this function and bulk edit, which is
+        // only accessible for admin users.
+       $sql =
+           "insert into " . DB_PREFIX . "photo_albums " .
+           "(photo_id, album_id) values ('" .
             escape_string($this->get("photo_id")) . "', '" .
             escape_string($album_id) . "')";
-        execute_query($sql, 1);
+        
+        if($user) {
+            $album_permissions=$user->get_album_permissions($album_id);
+
+            if($user->is_admin() || $album_permissions->get("writable")) {
+                execute_query($sql, 1);
+            }
+        } else {
+            execute_query($sql, 1);
+        }
     }
 
     function remove_from_album($album_ids) {
@@ -716,7 +728,7 @@ return "<img src=\"$image_href\" class=\"" . $type . "\" " . $size_string . " al
                    remove_magic_quotes($real_key);
                 }
 
-                $out_array[$real_key] = translate($real_key, 0) . ": " .
+            $out_array[$real_key] = translate($real_key, 0) . ": " .
                     $real_val;
                 $lines += ceil(strlen($out_array[$real_key]) / $maxWidthChars);
             }
@@ -942,6 +954,38 @@ echo ("<br>\noutString:<br>\n" . $out_string);
         $result=mysql_query($sql)
             or die_with_mysql_error("Could not delete relation:<br><i>$sql</i>");
     }    
+    
+    function exif_to_html() {
+        if (exif_imagetype($this->get_file_path())==IMAGETYPE_JPEG) {
+            $exif=read_exif_data($this->get_file_path());
+            if ($exif) {
+                $return="<dl id=\"allexif\">\n";
+
+                foreach($exif as $key => $value) {
+                    if(!is_array($value)) {
+                        $return .="    <dt>$key</dt>\n" .
+                                  "    <dd>" . preg_replace("/[^[:print:]]/", "", $value) . "</dd>\n";
+                    } else {
+                        $return .="    <dt>$key</dt>\n" .
+                                  "    <dd>\n" .
+                                  "        <dl>\n";
+                        foreach ($value as $subkey => $subval) {
+                            $return .= "            <dt>$subkey</dt>\n" .
+                                       "            <dd>" . preg_replace("/[^[:print:]]/", "", $subval) . "</dd>\n";
+                        }
+                        $return .= "         </dl>\n" .
+                                   "    </dd>\n";
+                    }
+                }
+                $return .= "</dl><br>";
+            } else {
+                $return=false;
+            }
+        } else {
+            $return=false;
+        }
+        return $return;
+    }
 }
 
 function get_photo_sizes_sum() {
@@ -979,12 +1023,13 @@ function create_rating_graph($user) {
         $max_count = max($max_count, $row[1]);	
     	$ratings[($row[0] ? $row[0] : translate("Not rated"))]=$row[1];
 	}
-
+?>
+    <h3><?php echo translate("photo ratings") ?></h3>
+<?php
     if ($max_count) { 
     $table =
-        "<table class=\"ratings\">\n  <tr>\n    <th colspan=\"3\"><h3>" .
-        translate("photo ratings") . "</h3></th>\n  </tr>\n  <tr>\n    <th>" .
-        translate("rating") . "</th>\n    <th>&nbsp;</th>\n    " .
+        "<table class=\"ratings\">\n<tr>\n" .
+        "<th>" . translate("rating") . "</th>\n" .
         "<th>" . translate("count") . "</th>\n  </tr>\n";
 
     $scale = 150.0 / $max_count;
@@ -994,15 +1039,15 @@ function create_rating_graph($user) {
 	   $min_rating=$range-0.5;
 	   $max_rating=$range+0.5;
            $qs =
-              "search.php?rating%5B0%5D=" . $min_rating . "&_rating_op%5B0%5D=%3E%3D" .
-              "&rating%5B1%5D=" . $max_rating . "&_rating_op%5B1%5D=%3C&_action=" . translate("search");
+              "search.php?rating%5B0%5D=" . $min_rating . "&amp;_rating_op%5B0%5D=%3E%3D" .
+              "&amp;rating%5B1%5D=" . $max_rating . "&amp;_rating_op%5B1%5D=%3C&amp;_action=" . translate("search");
         } else {
            $qs = "photos.php?rating=null";
         }  
         $table .=
             "  <tr>\n    <td>\n" .
             "      <a href=\"$qs\">$range</a></td>\n" .
-            "    <td>&nbsp;</td>\n    <td>\n";
+            "      <td>\n";
 
 	$table .= "<div class=\"ratings\" style=\"width: " . ceil($scale * $count) . "px;\">&nbsp;</div>";
         $table .= "[$count]\n    </td>\n  </tr>\n";
@@ -1013,8 +1058,7 @@ function create_rating_graph($user) {
     }
     else {
         $table .=
-            "  <tr>\n    <td colspan=\"2\" class=\"center\">\n" .
-            translate("No photo was found.") . "\n    </td>\n  </tr>\n";
+            translate("No photo was found.") . "\n";
     }
 
     return $table;
