@@ -24,6 +24,10 @@
     $_dir = getvar("_dir");
     $_show = getvar("_show");
 
+    if(!preg_match("/^[a-zA-Z_]*$/", $_order)) {
+        die("Illegal characters in _order");
+    }
+
     if (!$_cols) { $_cols = $DEFAULT_COLS; }
     if (!$_rows) { $_rows = $DEFAULT_ROWS; }
     if (!$_off)  { $_off = 0; }
@@ -61,7 +65,7 @@
 
         $num = min($cells, $num_thumbnails);
 
-        $name = $lightbox ? "Lightbox" : "Photos";
+        $name = isset($lightbox) ? "Lightbox" : "Photos";
 
         $title = sprintf(translate("$name (Page %s/%s)", 0), $page_num, $num_pages);
         $title_bar = sprintf(translate("photos %s to %s of %s"), ($offset + 1), ($offset + $num), $num_photos);
@@ -94,7 +98,7 @@
         <?php echo $title_bar . "\n" ?>
     </h1>
     <div class="main">
-        <form action="photos.php" method="GET">
+        <form class="viewsettings" action="photos.php" method="GET">
 <?php
     if ($num_thumbnails <= 0) {
 ?>
@@ -114,12 +118,12 @@
                 <a href="photos.php?<?php echo update_query_string($request_vars, "_dir", "desc") ?>"><img class="down" alt="sort descending" src="images/down<?php echo $_dir == "asc" ? 2 : 1 ?>.gif"></a>
             </div>
             <div id="rowscols">
-                <?php
-		echo create_integer_pulldown("_rows", $_rows, 1, 10);
+<?php
+                echo create_integer_pulldown("_rows", $_rows, 1, 10);
                 echo translate("rows") . "\n";
                 echo create_integer_pulldown("_cols", $_cols, 1, 10);
                 echo translate("cols") . "\n";
-		?>
+?>
                 <input type="submit" name="_button" value="<?php echo translate("go", 0) ?>">
 	    </div>
         </form>
@@ -145,7 +149,7 @@
             } else {
                 echo $thumbnails[$i]->get_thumbnail_link("photo.php?" . update_query_string($request_vars, "_off", $offset + $i, $ignore)) . "\n"; 
             }
-            if ($desc_thumbnails && $thumbnails[$i]->get("description")) {
+            if (!empty($desc_thumbnails) && $thumbnails[$i]->get("description")) {
 ?>
                 <br>
                 <div class="thumbdesc"><?php echo substr($thumbnails[$i]->get("description"), 0, MAX_THUMB_DESC) ?></div>
@@ -153,8 +157,8 @@
                 if (strlen($thumbnails[$i]->get("description")) > MAX_THUMB_DESC) { echo "..."; }
             }
 
-            if ($lightbox) {
-                if (!defined($desc_thumbnails)) { echo "<br>\n"; }
+            if (!empty($lightbox)) {
+                if (!isset($desc_thumbnails)) { echo "<br>\n"; }
 ?>
                 <div class="actionlink"><a href="photos.php?<?php echo update_query_string($request_vars, "_photo_id", $thumbnails[$i]->get("photo_id"), $ignore) ?>">x</a></div>
 <?php
