@@ -30,31 +30,38 @@ function get_url() {
     return $url;
 }
 
-function create_field_html($fields, $cols = 2, $split = null) {
+function create_field_html($fields) {
 
     $html = "";
-    if ($split) {
-        $left_tag = "          <td class=\"fieldtitle\" width=\"$split\">";
-        $right_tag = "          <td class=\"field\" width=\"$split\">";
-    }
-    else {
-        $left_tag = "          <td class=\"fieldtitle\">";
-        $right_tag = "          <td class=\"field\">";
-    }
-
     while (list($key, $val) = each($fields)) {
         if ($val) {
             $html .=
-            "        <tr>\n" .
-            "$left_tag$key</td>\n" .
-            "$right_tag$val</td>\n";
-            for ($i = 2; $i < $cols; $i++) {
-                $html .= "$right_tag&nbsp;</td>\n";
-            }
-            $html .= "        </tr>\n";
+            "<dt>$key</dt>\n" .
+            "<dd>$val</dd>\n";
         }
     }
+    return $html;
+}
 
+function create_field_html_table($fields) {
+
+    $html = "";
+    while (list($key, $val) = each($fields)) {
+        if ($val) {
+            $html .=
+            "<tr>\n  <th>$key</th>\n" .
+            "  <td>$val</<td>\n</tr>\n";
+        }
+    }
+    return $html;
+}
+
+function create_edit_fields($fields) {
+    $html = "";
+    while(list($key, $field) = each($fields)) {
+        $html.=
+            "<label for=\"$key\">$field[0]</label>\n$field[1]<br>";
+    }
     return $html;
 }
 
@@ -65,6 +72,7 @@ function create_text_input($name, $value, $size = 20, $max = 32) {
 
 function create_pulldown($name, $value, $value_array, $extraopt = null) {
     $id=ereg_replace("^_+", "", $name);
+
     $html = "<select name=\"$name\" id=\"$id\" $extraopt>\n";
     while (list($val, $label) = each($value_array)) {
         if ($val == $value) { $selected = " selected"; }
@@ -112,12 +120,12 @@ function create_grouped_pulldown($name, $value, $value_array) {
     return $html;
 }
 
-function create_smart_pulldown($name, $value, $value_array) {
+function create_smart_pulldown($name, $value, $value_array, $extraopt = null) {
 
     $size = sizeof($value_array);
 
     if ($size <= GROUPED_PULLDOWN_SIZE) {
-        return create_pulldown($name, $value, $value_array);
+        return create_pulldown($name, $value, $value_array, $extraopt);
     }
     else if ($size <= MAX_PULLDOWN_SIZE) {
         return create_grouped_pulldown($name, $value, $value_array);
@@ -210,6 +218,32 @@ function create_photo_field_pulldown($var, $name = null) {
         "metering_mode" => translate("metering mode",0)));
 }
 
+function create_photo_text_pulldown($var, $name = null) {
+    return create_pulldown($var, $name, array(
+        "" => "&nbsp;",
+        "album" => translate("album",0),
+        "category" => translate("category",0),
+        "person" => translate("person",0),
+        "photographer" => translate("photographer",0)));
+}
+
+function create_view_pulldown($name, $value, $extraopt=null) {
+    return create_pulldown($name, $value, array(
+        "list" => translate("List",0), 
+        "tree" => translate("Tree",0), 
+        "thumbs" => translate("Thumbnails",0)), $extraopt);
+}
+
+function create_autothumb_pulldown($name, $value, $extraopt=null) {
+    return  create_pulldown($name, $value, array(
+        "oldest" => translate("Oldest photo",0), 
+        "newest" => translate("Newest photo",0), 
+        "first" => translate("Changed least recently",0), 
+        "last" => translate("Changed most recently",0), 
+        "highest" => translate("Highest ranked",0), 
+        "random" => translate("Random",0)), $extraopt);
+}
+
 /*
  * Remove any params without values and operator params without corresponding
  * fields (e.g. _album_id-op when there is no _album_id).  This can be called
@@ -302,7 +336,7 @@ function clean_request_vars($vars) {
             }
 
             //process "_field" type variables
-            if (substr($field, 0, 5) == "field" && (empty($interim_vars[$field]) || empty($interim_vars["_$field"]))) { continue; }
+            if (substr($field, 0, 5) == "field" && (empty($interim_vars[$field]) && empty($interim_vars["_$field"]))) { continue; }
         } else {
 
             //process "field" type variables
@@ -324,16 +358,18 @@ function update_query_string($vars, $new_key, $new_val, $ignore = null) {
     if (!$ignore) { $ignore = array(); }
     $ignore[] = "PHPSESSID";
     $ignore[] = "_crumb";
+    $qstr="";
+    if($vars) {
+        while (list($key, $val) = each($vars)) {
+            if (in_array($key, $ignore)) { continue; }
+            if ($key == $new_key) { continue; }
 
-    while (list($key, $val) = each($vars)) {
-        if (in_array($key, $ignore)) { continue; }
-        if ($key == $new_key) { continue; }
-
-        if ($qstr) { $qstr .= "&amp;"; }
-        if (is_array($val)) {
-            $qstr .= rawurlencode_array($key, $val);
-        } else {
-            $qstr .= rawurlencode($key) . "=" . rawurlencode($val);
+            if (!empty($qstr)) { $qstr .= "&amp;"; }
+            if (is_array($val)) {
+                $qstr .= rawurlencode_array($key, $val);
+            } else {
+                $qstr .= rawurlencode($key) . "=" . rawurlencode($val);
+            }
         }
     }
 
@@ -588,4 +624,30 @@ function running_on_windows() {
         return false;
     }
 }
+
+function get_autothumb_order($autothumb) {
+    switch ($autothumb) {
+    case "oldest":
+        $order="ORDER BY p.date, p.time DESC LIMIT 1";
+        break;
+    case "newest":
+        $order="ORDER BY p.date DESC, p.time DESC LIMIT 1";
+        break;
+    case "first":
+        $order="ORDER BY p.timestamp LIMIT 1";
+        break;
+    case "last":
+        $order="ORDER BY p.timestamp DESC LIMIT 1";
+        break;
+    case "random":    
+        $order="ORDER BY rand() LIMIT 1";
+        break;
+    default:
+    case "highest":
+        $order="ORDER BY p.rating DESC LIMIT 1";
+        break;
+    }
+    return $order;
+}
+
 ?>
