@@ -49,6 +49,7 @@ CREATE TABLE zoph_albums (
   parent_album_id int(11) NOT NULL default '0',
   album varchar(32) NOT NULL default '',
   album_description varchar(255) default NULL,
+  coverphoto int(11) default NULL,
   sortorder varchar(32) default NULL,
   PRIMARY KEY  (album_id),
   KEY album_parent_id (parent_album_id)
@@ -59,7 +60,7 @@ CREATE TABLE zoph_albums (
 --
 
 
-INSERT INTO zoph_albums VALUES (1,0,'Album Root',NULL, NULL);
+INSERT INTO zoph_albums VALUES (1,0,'Album Root',NULL, NULL, NULL);
 
 --
 -- Table structure for table 'zoph_categories'
@@ -70,6 +71,7 @@ CREATE TABLE zoph_categories (
   parent_category_id int(11) NOT NULL default '0',
   category varchar(32) NOT NULL default '',
   category_description varchar(255) default NULL,
+  coverphoto int(11) default NULL,
   sortorder varchar(32) default NULL,
   PRIMARY KEY  (category_id),
   KEY cat_parent_id (parent_category_id)
@@ -80,7 +82,7 @@ CREATE TABLE zoph_categories (
 --
 
 
-INSERT INTO zoph_categories VALUES (1,0,'Category Root',NULL,NULL);
+INSERT INTO zoph_categories VALUES (1,0,'Category Root',NULL,NULL,NULL);
 
 --
 -- Table structure for table 'zoph_color_schemes'
@@ -152,6 +154,7 @@ CREATE TABLE zoph_people (
   mother_id int(11) default NULL,
   spouse_id int(11) default NULL,
   notes varchar(255) default NULL,
+  coverphoto int(11) default NULL,
   email varchar(64) default NULL,
   PRIMARY KEY  (person_id),
   KEY person_last_name (last_name(10)),
@@ -163,7 +166,7 @@ CREATE TABLE zoph_people (
 --
 
 
-INSERT INTO zoph_people VALUES (1,'Unknown','Person',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);
+INSERT INTO zoph_people VALUES (1,'Unknown','Person',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);
 
 --
 -- Table structure for table 'zoph_photo_albums'
@@ -301,13 +304,14 @@ CREATE TABLE zoph_places (
   country varchar(32) default NULL,
   url varchar(1024) DEFAULT NULL,
   urldesc varchar(32) DEFAULT NULL,
+  coverphoto int(11) default NULL,
   notes varchar(255) default NULL,
   PRIMARY KEY  (place_id),
   KEY place_city (city(10)),
   KEY place_title (title(10))
 ) TYPE=MyISAM;
 
-INSERT INTO zoph_places VALUES (0,0,0,"World",NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);
+INSERT INTO zoph_places VALUES (0,0,0,"World",NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);
 
 --
 -- Dumping data for table 'zoph_places'
@@ -334,9 +338,18 @@ CREATE TABLE zoph_prefs (
   recent_photo_days smallint(6) NOT NULL default '7',
   auto_edit char(1) NOT NULL default '0',
   camera_info char(1) NOT NULL default '1',
+  allexif char(1) NOT NULL default '0',
+  autocomp_albums char(1) default '1',
+  autocomp_places char(1) default '1',
+  autocomp_categories char(1) default '1',
+  autocomp_photographer char(1) default '1',
+  autocomp_people char(1) default '1',
   desc_thumbnails char(1) NOT NULL default '0',
   fullsize_new_win char(1) NOT NULL default '0',
   people_slots tinyint(3) NOT NULL default 1,
+  view enum('list','tree','thumbs') default 'list' NOT NULL,
+  autothumb enum('oldest','newest','first','last','highest','random') 
+  	default 'highest' NOT NULL,
   PRIMARY KEY  (user_id)
 ) TYPE=MyISAM;
 
@@ -345,7 +358,7 @@ CREATE TABLE zoph_prefs (
 --
 
 
-INSERT INTO zoph_prefs VALUES (1,'1',8,3,4,10,0,5,1,5,NULL,7,'0','1','0','0','1');
+INSERT INTO zoph_prefs VALUES (1,'1',8,3,4,10,0,5,1,5,NULL,7,'0','1','0','1','1','1','1','1','0','0','1','list','highest');
 
 --
 -- Table structure for table 'zoph_photo_ratings'
